Constants — Rucio 0.3.8 documentation

# Constants

Constants.

Each constant is in the format:
  CONSTANT_NAME = VALUE, DESCRIPTION

VALUE is what will be stored in the DB. DESCRIPTION is the meaningful string for client

class `rucio.db.constants.` `AccountStatus`

  Bases: `rucio.db.enum.DeclEnum`

  `ACTIVE` = ACTIVE
  `DELETED` = DELETED
  `SUSPENDED` = SUSPENDED

class `rucio.db.constants.` `AccountType`

  Bases: `rucio.db.enum.DeclEnum`

  `GROUP` = GROUP
  `SERVICE` = SERVICE
  `USER` = USER

class `rucio.db.constants.` `BadFilesStatus`

  Bases: `rucio.db.enum.DeclEnum`

  `BAD` = BAD
  `DELETED` = DELETED
  `RECOVERED` = RECOVERED
  `SUSPICIOUS` = SUSPICIOUS

class `rucio.db.constants.` `DIDAvailability`

  Bases: `rucio.db.enum.DeclEnum`

  `AVAILABLE` = AVAILABLE
  `DELETED` = DELETED
  `LOST` = LOST

class `rucio.db.constants.` `DIDReEvaluation`

  Bases: `rucio.db.enum.DeclEnum`

  `ATTACH` = ATTACH
  `DETACH` = DETACH

class `rucio.db.constants.` `DIDType`

  Bases: `rucio.db.enum.DeclEnum`

  `CONTAINER` = CONTAINER
  `DATASET` = DATASET
  `DELETED_CONTAINER` = DELETED_CONTAINER
  `DELETED_DATASET` = DELETED_DATASET
  `DELETED_FILE` = DELETED_FILE
  `FILE` = FILE

class `rucio.db.constants.` `FTSCompleteState`

  Bases: `rucio.db.enum.DeclEnum`

  `ERROR` = Error
  `OK` = Ok

class `rucio.db.constants.` `FTSState`

  Bases: `rucio.db.enum.DeclEnum`

  `ACTIVE` = ACTIVE
  `CANCELED` = CANCELED
  `FAILED` = FAILED
  `FINISHED` = FINISHED
  `FINISHEDDIRTY` = FINISHEDDIRTY
  `READY` = READY
  `SUBMITTED` = SUBMITTED

class `rucio.db.constants.` `IdentityType`

  Bases: `rucio.db.enum.DeclEnum`

  `GSS` = GSS
  `USERPASS` = USERPASS
  `X509` = X509

class `rucio.db.constants.` `KeyType`

  Bases: `rucio.db.enum.DeclEnum`

  `ALL` = ALL
  `COLLECTION` = COLLECTION
  `CONTAINER` = CONTAINER
  `DATASET` = DATASET
  `DERIVED` = DERIVED
  `FILE` = FILE

class `rucio.db.constants.` `LockState`

  Bases: `rucio.db.enum.DeclEnum`

  `OK` = OK
  `REPLICATING` = REPLICATING
  `STUCK` = STUCK

class `rucio.db.constants.` `RSEType`

  Bases: `rucio.db.enum.DeclEnum`

  `DISK` = DISK
  `TAPE` = TAPE

class `rucio.db.constants.` `ReplicaState`

  Bases: `rucio.db.enum.DeclEnum`

  `AVAILABLE` = AVAILABLE
  `BAD` = BAD
  `BEING_DELETED` = BEING_DELETED
  `COPYING` = COPYING
  `SOURCE` = SOURCE
  `UNAVAILABLE` = UNAVAILABLE

class `rucio.db.constants.` `RequestState`

  Bases: `rucio.db.enum.DeclEnum`

  `DONE` = DONE
  `FAILED` = FAILED
  `LOST` = LOST
  `QUEUED` = QUEUED
  `SUBMITTED` = SUBMITTED
  `SUBMITTING` = SUBMITTING

class `rucio.db.constants.` `RequestType`

  Bases: `rucio.db.enum.DeclEnum`

  `DOWNLOAD` = DOWNLOAD
  `STAGEIN` = STAGEIN
  `STAGEOUT` = STAGEOUT
  `TRANSFER` = TRANSFER
  `UPLOAD` = UPLOAD

class `rucio.db.constants.` `RuleGrouping`

  Bases: `rucio.db.enum.DeclEnum`

  `ALL` = ALL
  `DATASET` = DATASET
  `NONE` = NONE

class `rucio.db.constants.` `RuleNotification`

  Bases: `rucio.db.enum.DeclEnum`

  `CLOSE` = CLOSE
  `NO` = NO
  `YES` = YES

class `rucio.db.constants.` `RuleState`

  Bases: `rucio.db.enum.DeclEnum`

  `OK` = OK
  `REPLICATING` = REPLICATING
  `STUCK` = STUCK
  `SUSPENDED` = SUSPENDED

class `rucio.db.constants.` `ScopeStatus`

  Bases: `rucio.db.enum.DeclEnum`

  `CLOSED` = CLOSED
  `DELETED` = DELETED
  `OPEN` = OPEN

class `rucio.db.constants.` `SubscriptionState`

  Bases: `rucio.db.enum.DeclEnum`

  `ACTIVE` = ACTIVE
  `BROKEN` = BROKEN
  `INACTIVE` = INACTIVE
  `NEW` = NEW
  `UPDATED` = UPDATED